==> ponyc-0.13.0-1-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/itertools-Zip3.md <==
# Zip3\[A: A, B: B, C: C\]

Zip three iterators together so that each call to next() results in
the a tuple with the next value of the first iterator, the next value
of the second iterator, and the value of the third iterator. The
number of items returned is the minimum of the number of items
returned by the three iterators.

## Example Program

Print the following:

```
1 a 0.5
2 b 9.8
3 c 3.3
```

```pony
use "itertools"

actor Main
  new create(env: Env) =>
    var i1: Array[I32] ref = [as I32: 1, 2, 3]
    var i2: Array[String] ref = ["a", "b", "q", "f"]
    var i3: Array[Float] ref = [as F32: 0.5, 9.8, 3.3]

    for (x, y, z) in Zip3[I32, String, F32](i1.values(), i2.values(),
      i3.values()) do
      env.out.print("".add(x.string()).add(" ").add(y).add(" ")
        .add(z.string()))
    end
```


```pony
class ref Zip3[A: A, B: B, C: C] is
  Iterator[(A , B , C)] ref
```

#### Implements

* [Iterator](builtin-Iterator)\[(A , B , C)\] ref

---

## Constructors

### create

```pony
new ref create(
  i1: Iterator[A] ref,
  i2: Iterator[B] ref,
  i3: Iterator[C] ref)
: Zip3[A, B, C] ref^
```
#### Parameters

*   i1: [Iterator](builtin-Iterator)\[A\] ref
*   i2: [Iterator](builtin-Iterator)\[B\] ref
*   i3: [Iterator](builtin-Iterator)\[C\] ref

#### Returns

* [Zip3](itertools-Zip3)\[A, B, C\] ref^

---

## Public Functions

### has_next

```pony
fun ref has_next()
: Bool val
```

#### Returns

* [Bool](builtin-Bool) val

---

### next

```pony
fun ref next()
: (A , B , C) ?
```

#### Returns

* (A , B , C) ?

---

==> ponyc-0.18.0-1-x86_64.pkg.tar.xz: usr/share/doc/pony/stdlib-docs/docs/itertools-Zip3.md <==
# Zip3\[A: A, B: B, C: C\]

Zip three iterators together so that each call to next() results in
a tuple with the next value of the first iterator, the next value
of the second iterator, and the value of the third iterator. The
number of items returned is the minimum of the number of items
returned by the three iterators.

## Example Program

Print the following:

```
1 a 0.5
2 b 9.8
3 c 3.3
```

```pony
use "itertools"

actor Main
  new create(env: Env) =>
    var i1: Array[I32] ref = [as I32: 1; 2; 3]
    var i2: Array[String] ref = ["a"; "b"; "c"; "d"]
    var i3: Array[F32] ref = [as F32: 0.5; 9.8; 3.3]

    for (x, y, z) in Zip3[I32, String, F32](
      i1.values(), i2.values(), i3.values())
    do
      env.out.print(""
        .add(x.string()).add(" ")
        .add(y).add(" ")
        .add(z.string()))
    end
```


```pony
class ref Zip3[A: A, B: B, C: C] is
  Iterator[(A , B , C)] ref
```

#### Implements

* [Iterator](builtin-Iterator)\[(A , B , C)\] ref

---

## Constructors

### create

```pony
new ref create(
  i1: Iterator[A] ref,
  i2: Iterator[B] ref,
  i3: Iterator[C] ref)
: Zip3[A, B, C] ref^
```
#### Parameters

*   i1: [Iterator](builtin-Iterator)\[A\] ref
*   i2: [Iterator](builtin-Iterator)\[B\] ref
*   i3: [Iterator](builtin-Iterator)\[C\] ref

#### Returns

* [Zip3](itertools-Zip3)\[A, B, C\] ref^

---

## Public Functions

### has_next

```pony
fun ref has_next()
: Bool val
```

#### Returns

* [Bool](builtin-Bool) val

---

### next

```pony
fun ref next()
: (A , B , C) ?
```

#### Returns

* (A , B , C) ?

---
